# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# Set up some color-code tables for later use.   This  somewhat  experimental 
# module is used by the Map, NDCprocesses and NEtrend scripts (and maybe some
# others) as a central place to coordinate all their color features.        
#
# The usual way that this module is used in wish scripts is:
#    source colors.w
#    LoadColors
# Then the C() array will be loaded with the colors in the colorList, and any
# routine that wishes to use them can declare "global C" and access the color
# by name.  There are also some abbreviations used.  Try declaring:
#    global C Cb Ce Cd Ci Cl Cf Cm
# These declare a set of colors in a form usable in widget declarations.  The
# colors are:
#    Cb C(buttonBackground)
#    Ce C(entryBackground)
#    Cd C(dataBackground)
#    Ci C(infoBackground)	-- Information, data fields.
#    Cl C(infoBackground)	-- Labels (fixed text).
#    Cf C(infoBackground)	-- Frames.
#    Cm C(menuBackground)
# These declare both foreground and background colors, as appropriate.   They
# also  include  -bd  and  -relief  options  when appropriate.  Here are some
# typical examples of their use:
#    eval frame .dialog.data $Cf
#    eval label .dialog.text $Ci -text {{Map name:}}
#    eval entry .dialog.name $Ce -textvariable mapname
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #

source fetch.tcl
source store.tcl

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# Here's a list of the required colors. The LoadColors routine will make sure #
# that  all  of  these are in the C array, whether or not they are in a color #
# directory. We list both the name of the color and the name of its file, but #
# at present they are always the same.  It's probably not a good idea to make #
# them different, so we might eliminate the difference eventually.            #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
#   {colorName        colorFile        default}                               #
set colorList {
	{Background       Background       grey50}
	{Border0          Border0          black}
	{Border1          Border1          green}
	{Border2          Border2          blue}
	{Border3          Border3          red}
	{Foreground       Foreground       grey90}
	{OK               OK               grey90}
	{bbar             bbar             grey40}
	{buttonBackground buttonBackground grey50}
	{buttonForeground buttonForeground grey10}
	{dataBackground   dataBackground   grey50}
	{dataForeground   dataForeground   yellow}
	{entryBackground  entryBackground  grey50}
	{entryForeground  entryForeground  grey10}
	{error            error            red2}
	{warning          warning          orange}
	{graphBackground  graphBackground  grey60}
	{helpBackground   helpBackground   grey50}
	{helpForeground   helpForeground   grey10}
	{iconBackground   iconBackground   grey50}
	{iconForeground   iconForeground   grey90}
	{infoBackground   infoBackground   grey50}
	{infoForeground   infoForeground   grey90}
	{link             link             grey90}
	{map              map              grey50}
	{markICMP         markICMP         brown2}
	{markIPAD         markIPAD         grey70}
	{markNDC          markNDC          brown3}
	{markSNMP         markSNMP         brown4}
	{mbar             mbar             grey50}
	{menuBackground   menuBackground   grey50}
	{menuForeground   menuForeground   yellow}
	{msgBackground    msgBackground    grey50}
	{msgForeground    msgForeground    grey10}
	{nameBackground   nameBackground   grey50}
	{nameForeground   nameForeground   grey90}
	{procBackground   procBackground   grey50}
	{procForeground   procForeground   grey90}
}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# These colors are used for OperStatus and MsgCode variables:
proc DefineColors {} {
	global D clrOperStatus clrMsgCode colordir
	set clrOperStatus(0) [fetch $colordir/unknown   white]
	set clrOperStatus(1) [fetch $colordir/running   cyan]
	set clrOperStatus(2) [fetch $colordir/succeeded green]
	set clrOperStatus(3) [fetch $colordir/failed    red3]
	set clrOperStatus(4) [fetch $colordir/alarm     red3]
	set clrMsgCode(0)    [fetch $colordir/OK        white]
	set clrMsgCode(1)    [fetch $colordir/Info      cyan]
	set clrMsgCode(2)    [fetch $colordir/Warning   green]
	set clrMsgCode(3)    [fetch $colordir/Problem   yellow]
	set clrMsgCode(4)    [fetch $colordir/Serious   orange]
	set clrMsgCode(5)    [fetch $colordir/Fatal     red3]
}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# The following colors are used for background in various  frames.   We  give #
# them  contrasting  dark  colors during debugging, and then set them to grey #
# for the final product. Q:  Is there a way to learn the X resource color for #
# "background" here?                                                          #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
proc bgColors {} {
	global C D bg Background
	if {$D} {
		set bg(0) grey50
		set bg(1) black
		set bg(2) brown
		set bg(3) DarkGreen
		set bg(4) navy
		set bg(5) SeaGreen4
	} else {
		set bg(0) $C(Background)	;# grey50
		set bg(1) $C(Background)	;# grey50
		set bg(2) $C(Background)	;# grey50
		set bg(3) $C(Background)	;# grey50
		set bg(4) $C(Background)	;# grey50
		set bg(5) $C(Background)	;# grey50
	}
}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# Load two fixed colors into the bg and fg arrays. This is obsolescent; it is #
# being  replaced  by C(buttonBackground) and C(buttonForeground) in the more #
# general C array.                                                            #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
proc ButtonColors {} {
	global bg fg
	set bg(Button) tan
	set fg(Button) navy
}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# Here's a routine to draw a color palette window.  The window lists all  the #
# colors  in  the C array, showing their current values.  The user can change #
# them.  There is an Apply button that calls Reinit; your program must define #
# a  Reinit  function  if you call this Palette function.  The expectation is #
# that Reinit will totally redraw everything, using the current colors. There #
# is  also  a  Save  button  that  allows  the user to save the colors in the #
# directory named in the colordir variable.                                   #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
proc Palette {} {
	global B C D R .palette colordir Ce Cf Ci
	if [winfo exists .palette] {
		destroy .palette.f	;# Rebuild its contents.
	} else {
		toplevel .palette	;# Initial palette creation.
	}
	frame .palette.f
	pack  .palette.f -in .palette -expand 1 -fill both
	frame .palette.f.fdir -bd 5 -relief ridge
	label .palette.f.ldir -bd $B -relief $R -text "Dir: "
	entry .palette.f.edir -bd $B -relief $R -textvariable colordir
	pack  .palette.f.ldir -in .palette.f.fdir -side left
	pack  .palette.f.edir -in .palette.f.fdir -side left -expand y -fill x
	pack  .palette.f.fdir -in .palette.f -expand y -fill both
	bind  .palette.f.edir <Return> Palette
	foreach c [lsort [array names C]] {
		if [regexp {^\.} $c] {
			if {$D>2} {puts "Palette: Ignore $c"}
			continue
		}
		if {$D>4} {puts "Palette: C($c) is \"$C($c)\""}
		eval frame .palette.f.f$c $Cf
		eval label .palette.f.l$c $Ci -text {"$c: "} -width 20 -anchor e 
		eval entry .palette.f.c$c $Ce -textvariable C($c) 
		pack .palette.f.l$c .palette.f.c$c -in .palette.f.f$c -side left
		pack .palette.f.f$c -in .palette.f -expand 1 -fill y
	}
	frame .palette.f.b  -bd 5 -relief ridge
	button .palette.f.bOK     -bd 3 -relief raised \
		-bg $C(buttonBackground) -fg $C(buttonForeground) \
		-text OK     -command {Reinit; destroy .palette}
	button .palette.f.bApply  -bd 3 -relief raised \
		-bg $C(buttonBackground) -fg $C(buttonForeground) \
		-text Apply  -command {Reinit}
	button .palette.f.bSave   -bd 3 -relief raised \
		-bg $C(buttonBackground) -fg $C(buttonForeground) \
		-text Save   -command {SaveColors}
	button .palette.f.bCancel -bd 3 -relief raised \
		-bg $C(buttonBackground) -fg $C(buttonForeground) \
		-text Cancel -command {destroy .palette}
	pack .palette.f.bOK .palette.f.bApply .palette.f.bSave .palette.f.bCancel -in .palette.f.b \
		-side left -expand 1 -fill both -padx 3
	pack .palette.f.b -in .palette.f -expand 1 -fill both
	bind .palette.f.edir <ButtonPress-3> {
		set xcur %x
		set ycur %y
		if {$D>4} {puts "ButtonPress-3 at xcur=$xcur ycur=$ycur"}
		set b2down 1
		ColorDirMenu %X %Y %W
	}
	raise .palette
}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# This routine produces the menu of color directory names; it is bound to <3> #
# in the directory name field (.palette.f.edir) within the palette window.    #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
proc ColorDirMenu {x y w} {
	global C D .cdirmenu colordir
	if [info exists C(menuBackground)] {} else {set C(menuBackground) grey50}
	if [winfo exists .cdirmenu] {destroy .cdirmenu}
	menu .cdirmenu -bg $C(menuBackground) -fg $C(menuForeground)
	foreach d [lsort [glob color*]] {
		if [file isdirectory $d] {
			.cdirmenu add command -label $d -command "set colordir $d; LoadColors"
		}
	}
	tk_popup .cdirmenu $x $y
}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# Return a color name for message code m.
proc MsgColor {m} {
	global clrMsgCode
	if [info exists clrMsgCode($m)] {return $clrMsgCode($m)} else {return white}
}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# Load each color name from the appropriate file in the colordir. We run thru #
# the  color directory, and treat each file's name as a color-usage name; the #
# first line of the file is the color name or hex value. We also run thru the #
# colorlist, and make sure that everything named there is loaded, as a way ot #
# guaranteeing that a specific set of colors are loaded.                      #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
proc LoadColors {} {
	global B C D F R colordir colorList errMsg Cl Ci Cf Ce Cd Cb Cm
	if ![info exists F] {set F 3}
	if ![info exists colordir] {set colordir color}
	if {$D>3} {puts "Color directory is \"$colordir\""}
	if [file isdirectory $colordir] {
		foreach c [exec ls $colordir]] {
			if [catch {open $colordir/$c r} f] {
				set errMsg $f
			} else {
				gets $f v
				if {$D>4} {puts "LoadColors: C($c) is \"$v\""}
				set C($c) $v
				close $f
			}
		}
	} else {
		if {$D} {puts "LoadColors: No $colordir directory."}
	}
	foreach t $colorList {
		set n [lindex $t 0]
		global $n
		set C($n) [set $n [fetch $colordir/[lindex $t 1] [lindex $t 2]]]
		if {$D>4} {puts "Color $n is \"$C($n)\""}
	}
	set Cb "-fg $C(buttonForeground) -bg $C(buttonBackground)"
	set Ce "-bd $B -relief sunken -fg $C(entryForeground) -bg $C(entryBackground)"
	set Cd "-bd $B -relief $R -fg $C(dataForeground) -bg $C(dataBackground)"
	set Ci "-bd $B -relief $R -fg $C(infoForeground) -bg $C(infoBackground)"
	set Cl "-bd $B -relief $R -fg $C(infoForeground) -bg $C(infoBackground)"
	set Cf "-bd $B -relief $R -bg $C(infoBackground)"
	set Cm "-bd 2 -relief raised -fg $C(menuForeground) -bg $C(menuBackground)"
	return 0
}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# Save the current script's colors in the color directory.  We save both  the #
# contents  of  the  C  array, and all the colors in the colorList, to handle #
# both of the schemes that are in use.  Eventually, we want to phase out  the #
# use of the colorList, and convert everything to use the C array.            #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
proc SaveColors {} {
	global B C D R colordir colorList 
	if [file isdir $colordir] {} else {
		exec mkdir $colordir
	}
	foreach c [array names C] {
		if {$D>4} {puts "SaveColors: Save C($c)=$C($c) in $colordir/$c"}
		store $colordir/$c $C($c)
	}
}
