# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# Here's a routine to decide what to display in a map  for  an  icon's  name. #
# Depending  on  $labelstyle,  we  generate any of several different strings. #
# This routine only makes sense inside the Map script at present; it is in  a #
# separate file for convenience in working on several versions.               #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# We distinguish the following values for $labelstyle:
#   n   name only.
#   a   One address only.
#   A   All addresses.
#   b   Both name and one address.
#   +   Everything.
#   -   Nothing.

proc displayLabel {name} {
	global D labelstyle .fMap 
	set lbl {}
	switch "X$labelstyle" {
	Xn	{		;# Name only.
		if {[string index $name 0] != "#"} {
			set lbl $name
		}
	}
	XA	{		;# All addresses.
		if [catch {exec ipads $name} lbl] {
			if {$D>1} {puts "displayLabel: ipad failed for \"$name\""}
			set lbl {}
		} else {
			if {$D>1} {puts "displayLabel: ipad \"$name\" gave lbl=\"$lbl\""}
		}
	}
	Xa	{		;# First address only.
		if [catch {exec ipad $name} lbl] {
			if {$D>1} {puts "displayLabel: ipad failed for \"$name\""}
			set lbl {}
		} else {
			if {$D>1} {puts "displayLabel: ipad \"$name\" gave lbl=\"$lbl\""}
		}
	}
	X-	{		;# No label.
	}
	Xb	{		;# Both: Name and one address.
		regsub {^[#.]*} $name {} n
		set a [exec ipad $name]
		set lbl "$n\n$a"
	}
	X+	{		;# All: Name and all addresses.
		regsub {^[#.]*} $name {} n
		if [catch {exec ipads $name} lbl] {
			if {$D>1} {puts "displayLabel: ipad failed for \"$name\""}
			set lbl {}
		} else {
			if {$D>1} {puts "displayLabel: ipad \"$name\" gave lbl=\"$lbl\""}
		}
		set a $lbl
		set lbl "$n\n$a"
	}
	default	{
		if {$D>1} {puts "displayLabel: unknown style \"$labelstyle\""}
	}
	}
	if {$D>1} {puts "displayLabel: name=\"$name\" lbl=\"$lbl\""}
	return $lbl
}
