
NAME

  RunProc - Run a command and generate SNMP information about it.

SYNOPSIS

  RunProc [procIndex] [redirect] name [args]...

KEYWORDS

  SNMP NDC process 

DESCRIPTION

  The RunProc program runs a  "name  args..."  as  a  subprocess,  and
  generates SNMP information in the NDC process table. RunProc is used
  by the NDC SNMP agent, ndcsnmpd, to  start  processes  remotely  and
  monitor their progress.  This makes it unnecessary for most programs
  to contain any special code for supplying process information to the
  agent (though some may have reason to do so in some situations).

  If the procIndex argument is present, it must be  a  small  integer,
  and  RunProc  will  put  the  information in that row of the process
  table, overwriting any  previous  entry  with  that  procIndex.   If
  procIndex  is omitted, RunProc will determine a value, but searching
  the existing table for a process with a matching name  (after  first
  stripping away any directory from the name). If you wish to have two
  processes with the same name, you must specify the procIndex for all
  but the lowest, or all their data will be put into the same row.

ARGUMENTS

  The command-line arguments are:

  procIndex
    A positive integer that is the desired  row  in  the  NDC  process
    table. It is best if the numbers are small, though RunProc and the
    agent don't actually care much how large they get.

  redirect
    A shell-style redirection for standard output.  If quoted so  that
    this  is  passed  to RunProc, stdout will be sent to the file, and
    the procLogFile MIB variable will be filled in  for  the  process.
    Thus a crontab entry might look like:
       7 * * * * /ndc/snmp/RunProc '>>/ndc/log/foo.bar.log' \
            /ndc/foo/bar

  name
    An executable program in RunProc's search path or a full pathname.

  args...
    Any number of command-line arguments, to be passed to the program
    via the usual argv[] mechanism.

  <community>
    The SNMP community string to use (public by default)

MIB VARIABLES

  The variables generated by RunProc are:

  procIndex
    The index itself, for cross-checking purposes.

  procPID
    The Unix process ID number.

  procName
    The process name, without any directory information.

  procStartTime
  procStopTime
    The Unix timestamp (seconds since the start of 1970 UT) at which the
    process was started, and when it exited.

  procOperStatus
    RunProc fills in the following values:
       1  running
       2  succeeded exit status zero)
       3  failed (exit status nonzero)

  procExitStatus
    The process's exit status code.

  procMsgCode
    RunProc generates the following message codes:
       256 Program doesn't exist or can't be executed.
       257 Process is already running.


  The process itself may also generate  values  for  these  variables.
  They  are  in  the  "/ndc/snmp/proc"  directory, and their names
  consist of the variable name, a dot, and the procIndex.   Thus,  the
  message code for process 7 is in "/ndc/snmp/proc/procMsgCode.7".

OPTIONS

  None.

ENVIRONMENT

  D_RunProc
    The debug level.  If defined, it should be a single digit; the log
    info goes to standard output.

FILES
  /ndc/snmp/proc/<variable>.<instance>
    These files contain the values of the NDC process  MIB  variables.
    The  agent  returns  the first line of each file as the variable's
    value.  Programs started by RunProc should have  write  access  to
    these files, and may fill in values as necessary.

  /ndc/snmp/agent.mib
  /ndc/snmp/mibtbl
    These  describe  the  MIB  implemented  by  the  NDC  SNMP  agent,
    ndcsnmpd.  The "agent.mib" file is the ASN-1 source; "mibtbl" is a
    compact table showing the OID and symbolic name of  each  variable
    in the table.

LOGFILE
  See D_RunProc above.

DEBUGGING
  See D_RunProc above.

SEE ALSO

BUGS
  

AUTHOR
  John Chambers <jmc0@gte.com>

