
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# This routine adds a menu item to the menu m:  a cascade that offers to  the #
# user the choice of rlogin or telnet. The cascade menu item is returned, and #
# ignored at present by the caller(s).                                        #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
proc LoginMenu {m name} {
	global B C D R .map fg n2p stICMP stSNMP statColor
	if {$D} {puts "LoginMenu $m $name"}
#	upvar #0 $menu m
	if {$D} {puts "LoginMenu: menu $m.lgin  -bg $C(menuBackground) -fg $C(menuForeground)"}
	menu $m.lgin  -bg $C(menuBackground) -fg $C(menuForeground)
	if {$D} {puts "LoginMenu: $m add cascade -label Connect -menu $m.lgin"}
	$m add cascade -label Connect -menu $m.lgin
	$m.lgin add command -label "rlogin to $name" -command "Login  $name"
	$m.lgin add command -label "telnet to $name" -command "Telnet $name"
	$m.lgin add command -label "ftp    to $name" -command "Ftp    $name"
	$m.lgin add command -label "Mosaic: ftp://$name" -command "MosaicFTP $name"
	$m.lgin add command -label "Mosaic: http://$name" -command "MosaicHTTP $name"
	$m.lgin add command -label "NetScape: $name" -command "NetScapeHTTP $name"
	return $m.lgin
}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# Here's where we implement the Login button.  We  launch  an  xterm  with  a #
# rlogin  command  to  the  current node.  This will only work if the node is #
# known to our nameserver, because rlogin doesn't accept IP  addresses,  only #
# symbolic node (host) names.                                                 #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
proc Login {n} {
	global B C D R currNode lgin p2n
	regsub {^#*} $n {} n
	set flgin "name-lgin/$n"
	set fhost "name-host/$n"
	if [file exists $fhost] {
		set fileid [open "name-host/$n"]
		set host [gets $fileid]
		if {$D} {puts "Login: Got host=\"$host\" from $fhost"}
		close $fileid
	} else {
		set host $n
	}
	if [file exists $flgin] {
		set fileid [open "name-lgin/$n"]
		set lgin [gets $fileid]
		if {$D} {puts "Login: Got lgin=\"$lgin\" from $flgin"}
		close $fileid
	} elseif [info exists env(USER)] {
		set lgin $env(USER)
	} elseif [info exists env(LOGNAME)] {
		set lgin $env(LOGNAME)
	} else {
		set lgin root
	}
	if {$host == {}} {
		if {$D>1} {puts "There is no current node."}
	} else {
		if {$D>1} {puts "Login: xterm -e rlogin $host -l $lgin"}
		exec xterm -e rlogin $host -l $lgin &
	}
}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# Here's where we implement the Mosaic button.  We launch Mosaic with  a  URL #
# derived from the current node name.                                         #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
proc MosaicFTP {n} {
	global B C D R currNode lgin p2n pidMosaic
	regsub {^#*} $n {} n
	set fhost "name-host/$n"
	set fipad "name-ipad/$n"
	if [file exists $fhost] {
		set fileid [open "name-host/$n"]
		set host [gets $fileid]
		if {$D} {puts "Mosaic: Got host=\"$host\" from $fhost"}
		close $fileid
	} elseif [file exists $fipad] {
		set fileid [open "name-ipad/$n"]
		set host [gets $fileid]
		if {$D} {puts "Mosaic: Got host=\"$host\" from $fhost"}
		close $fileid
	} else {
		set host $n
	}
	if {$n == {}} {
		if {$D>1} {puts "There is no current node."}
	} else {
		if {$D>1} {puts "Mosaic: ftp://$host/"}
		set pidMosaic [exec Mosaic "ftp://$host/" &]
	}
}
set pidMosaic 0

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# Here's where we implement the Mosaic button.  We launch Mosaic with  a  URL #
# derived from the current node name.                                         #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
proc MosaicHTTP {n} {
	global B C D R currNode lgin p2n pidMosaic
	regsub {^#*} $n {} n
	set fhost "name-host/$n"
	set fipad "name-ipad/$n"
	if [file exists $fhost] {
		set fileid [open "name-host/$n"]
		set host [gets $fileid]
		if {$D} {puts "Mosaic: Got host=\"$host\" from $fhost"}
		close $fileid
	} elseif [file exists $fipad] {
		set fileid [open "name-ipad/$n"]
		set host [gets $fileid]
		if {$D} {puts "Mosaic: Got host=\"$host\" from $fhost"}
		close $fileid
	} else {
		set host $n
	}
	if {$n == {}} {
		if {$D>1} {puts "There is no current node."}
	} else {
		if {$D>1} {puts "Mosaic: http://$host/"}
		set pidMosaic [exec Mosaic "http://$host/" &]
	}
}
set pidMosaic 0

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# Here's where we implement the NetScape button.  We launch NetScape with  a  URL #
# derived from the current node name.                                         #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
proc NetScapeHTTP {n} {
	global B C D R currNode lgin p2n pidNetScape
	regsub {^#*} $n {} n
	set fhost "name-host/$n"
	set fipad "name-ipad/$n"
	if [file exists $fhost] {
		set fileid [open "name-host/$n"]
		set host [gets $fileid]
		if {$D} {puts "NetScape: Got host=\"$host\" from $fhost"}
		close $fileid
	} elseif [file exists $fipad] {
		set fileid [open "name-ipad/$n"]
		set host [gets $fileid]
		if {$D} {puts "NetScape: Got host=\"$host\" from $fhost"}
		close $fileid
	} else {
		set host $n
	}
	if {$n == {}} {
		if {$D>1} {puts "There is no current node."}
	} else {
		if {$D>1} {puts "NetScape: http://$host/"}
		set pidNetScape [exec netscape "http://$host/" &]
	}
}
set pidNetScape 0

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
#
proc Ftp {n} {
	global B C D R currNode p2n
	if {$n == {}} {
		if {$D>1} {puts "Ftp: There is no current node."}
	} else {
		if {$D>0} {puts "Ftp: exec ipad $n ..."}
		if [catch {exec ipad $n} a] {
			if {$D} {puts "No IP address for \"$n\""}
		} else {
			if {$D} {puts "Ftp: IP address for \"$n\" is \"$a\""}
			if {$D>1} {puts "Ftp: xterm -e ftp $a"}
			exec xterm -e ftp $a &
		}
	}
}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
#
proc Telnet {n} {
	global B C D R currNode p2n
	if {$n == {}} {
		if {$D>1} {puts "Telnet: There is no current node."}
	} else {
		if {$D>0} {puts "Telnet: exec ipad $n ..."}
		if [catch {exec ipad $n} a] {
			if {$D} {puts "No IP address for \"$n\""}
		} else {
			if {$D} {puts "Telnet: IP address for \"$n\" is \"$a\""}
			if {$D>1} {puts "Telnet: xterm -e telnet $a"}
			exec xterm -e telnet $a &
		}
	}
}

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
# Get rid of an item in the current map.  This is triggered by the "Del Node" #
# button.   Deletion  may also be done via the Del key, which invokes the Del #
# procedure.  This DelNode routine requires that there be a selected node.    #
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
proc DelNode {} {
	global B C D R currNode me msg global p2n n2I n2t n2p n2x n2y maplist sel
	if {$D>0} {puts "DelNode ..."}
	set n $currNode
	if {$n == {}} {
		if {$D>0} {puts "There is no current node."}
		set msg "Nothing selected"
		return
	}
	if {[set l [lsearch $maplist $n]] >= 0} {	;# Is name in the current map?
		if {$D>0} {puts "DelNode: Delete item $l name $n from maplist"}
		set maplist [lreplace $maplist $l $l]	;# Delete the name.
	}
	if {$D>0} {puts "DelNode: delete tag $n from map"}
	.map delete $n 
	if [info exists sel($n)] {
		if {$sel($n)} {
			if {$D>0} {puts "Selected: $n is selected ..."}
			set sel($n) 0		;# Mark name as not selected.
		} else {
			if {$D>0} {puts "Selected: $n is not selected ..."}
			set msg "### DelNode found $n not selected"
			return
		}
	}
}

