
SNMPD(1)                    USER COMMANDS                      SNMPD(1)

NAME
   ndcagent - SNMP agent daemon

SYNOPSIS
   ndcagent [options]

DESCRIPTION
   Snmpd is an SNMP agent that runs as a background daemon process on a  Unix
   system.   It  opens  the SNMP port (udp/161 by default) and waits for SNMP
   requests to arrive.  If a request can be satisfied, ndcagent sends an SNMP
   reply message to the originator of the request.

   Although ndcagent has various options, it is designed to use the same sort
   of defaults as most other Unix SNMP agents, and will usually run correctly
   with  no  options or arguments at all.  Snmpd is designed to be started as
   part of the system's startup, from the /etc/rc* scripts or  via  inetd  or
   inittab.   For  testing purposes, it has a number of optional command-line
   arguments, and it will also use several variables from the environment, if
   they are defined.  It also reads from a config file if it is present.

   In normal operation, ndcagent must be run as root so that UDP port 161 can
   be opened; alternative you may use inetd to open the port, in  which  case
   ndcagent  may  be  run as an unprivileged user.  For testing, a port other
   than 161 may be used, and root permissions are not needed.   This  implies
   that  your  application  programs  must  also  have  a way of specifying a
   non-standard SNMP port.

   This version of ndcagent has been extended to include support for the  GTE
   NDC MIB.

OPTIONS
   Options may start with '-' or '+'. For some options, '-' means disable and
   '+'  means enable.  For others, this concept is irrelevant, and it doesn't
   matter which flag character you use.  In the descriptions below, '-' means
   that the flag character is irrelevant; '+' means that it is significant.

   After the flag char, options have with a single letter, which may be upper
   or lower case, possibly followed immediately by a parameter.

      -D<l><file>
      +D<l><file>
      %D<l><file>

   These all set the debug level to <l> (a single digit) and the  output  log
   file to <file>.  See the DEBUGGING section below.

      +e

   This tells the agent to return the "no such variable" error  (2)  when  it
   can't  get  data  for a variable because there's no GET routine in its MIB
   table.  The default for variables that are present but not yet implemented
   is NODATA (998).

      -H<c>

   This sets the hexdump format  to  the  character  <c>.   See  the  HEX_FMT
   environment variable below for details.

      +I

   This tells ndcagent to try to process each message as it is received. This
   is the original behavior of the CMU code.  The default (-I) is to read and
   queue all incoming messages, and then to process them.  For requests  that
   require  data from the remote (proxied) process, this option may result in
   much slower responses.

      +M

   This produces a symbolic dump of the MIB table during startup.  "-M"  does
   nothing at all (but might be useful for documentation).

      -N
      +N

   This tells the agent how to treat variables that are in its MIB table  but
   for  which  there  isn't  (yet)  a GET routine:  +N means to return a NULL
   value; -N means to return the SNMP "no such variable" error code, 2.

      -p<number>

   This specifies a UDP port number to be used for SNMP  messages.   See  the
   SNMP_PORT variable below.

      -SET
      +SET

   This says whether to implement read-only checking for SNMP SET operations.
   -SET  disables  SET  operations for all variables not labelled read-write;
   +SET tells ndcagent to disregard the "ACCESS  read-only"  MIB  clause  and
   allow  SETs  for  any  variables  that  are settable (i.e., the ones which
   ndcagent knows how to set).  This  is  independent  of  the  set-community
   mechanism;  clients  must  still have an acceptable set-community-name and
   set-community-addr to be allowed to perform SET operations.

      %varName

   An option consisting of a '%' and a MIB variable name  will  suppress  the
   variable.   This  is  primarily  for  use  during  testing, when there are
   problems with the handling of some variables.

      +u

   This tells the agent to return the "not implemented" error (999)  when  it
   can't  get  data  for a variable because there's no GET routine in its MIB
   table.

      +v

   This tells the agent to return the "no data" error (998) when it can't get
   data for a variable.

KEYWORDS
   Snmpd accepts a few command-line arguments in keyword=value format.

      PORT=<number>

   This is another way to specify the SNMP port number.  The default is  161.
   See SNMP_PORT below for more information.

      TRAP=<number>

   This specifies an SNMP TRAP port number. The default is 162. See SNMP_TRAP
   below for more information.

ENVIRONMENT
   Snmpd will use the following environment variables.  Note that some may be
   typed in two forms, with or without a '_'.

   ASN_FMT
     The format of the ASN.1 symbolic dumps produced at debug level  3
     and higher. The value is a single character, which may be any of:
       1    gives a single long line.
       2    puts each variable-value pair on a separate line.
       3    is fully indented, C-style, with each brace on a new line.
     The default is '2'.  This may also be set  in  the  ndcagent.conf
     config file by a "asn-fmt:" line.

   BACKUP
     This tells the agent how to back up its  logfile.   The  simplest
     value is a number: "setenv BACKUP .3" will cause it to make up to
     three backup files when the size limit is hit; the  backups  will
     have ".1", ".2" and ".3" appended to their names.

   DBG_SIZE
     This is the size limit for the debug/audit/log file.  The default
     is  1000000  (one  million)  bytes,  after which the file will be
     renamed to a backup and a new logfile will be started.

   CM_HOST CMHOST
     This is the hostname to be used to get the IP address  where  the
     remote (proxied) process is running; the default is "localhost".

   CM_PORT CMPORT
     This is the TCP/UDP port number for the remote (proxied) process;
     the default is 6010.

   CM_TCP CMTCP
     This is the TCP port number for the remote (proxied) process; the
     default is 6010.

   CM_UDP CMUDP
     This is the UDP port number for the remote (proxied) process; the
     default is 6010.

   CM_WAIT CMWAIT
     If defined, this will be used as the timeout in a  select()  call
     just after sending a message to the remote (proxied) process.  If
     undefined, ndcagent will  send  the  message  and  go  about  its
     business,  checking  occasionally  for  a  reply.   This  is  the
     preferred  behavior  except  during  testing,  and  use  of  this
     variable is discouraged outside the lab.

   HEX_FMT
     The format of hexdumps produced at debug level 3 and higher.  The
     value is a single character, which may be any of:
       3Vv  mean a 3-line "vertical" dump (the most readable).
       2Hh  mean a 2-line dump (which makes cut-and-paste easy)
       1    is the IBM-style single-line format, the least readable.
     The default is '3'.  This may also be set  in  the  ndcagent.conf
     config file by a "hex-fmt:" line.

   MIBFILE
     This should be the name of a file that contains the symbolic  MIB
     for the agent. It isn't actually used by ndcagent, but it is used
     by various SNMP test programs for displaying replies. We describe
     it here for completeness.

   PID_FILE PIDFILE
     The process id of the ndcagent program will be  written  to  this
     file, which is "ndcagent.pid" by default.

   SNMP_CONF SNMPCONF
     This is the name of the SNMP config file. The default config file
     is  "ndcagent.conf",  which  need  not  exist  for ndcagent to be
     usable.

   SNMP_DROP SNMPDROP
     This is the number of seconds that ndcagent will keep a  request.
     If  the data can't be found within that time, the message will be
     silently discarded.

   SNMP_HOST SNMPHOST
     This is the hostname to use when binding  to  a  UDP  port.   The
     default  is  to  use  a "wildcard" so that it can accept messages
     from all of the local machine's UDP ports.  This is mostly useful
     during  testing,  so  that  several copies of ndcagent may be run
     simultaneously (on `hostname` and "localhost").

   SNMP_MAX SNMPMAX
     This is the maximum size of an SNMP message. The default for this
     version  of  ndcagent is 1500, which is greater than the official
     SNMP maximum of 484 octets.  For local  communication,  any  size
     supported  by the kernel may be used; for remote agents, use of a
     size greater than the MTU of any intervening interface may result
     in loss of messages when the network is congested.

   SNMP_POLL SNMPPOLL
     How long (in seconds) data is kept; when a variable gets to be
     this  old, a request for the data will trigger another request
     for the record that contains the variable's data.  The default is
     10 seconds.

   SNMP_PORT SNMPPORT
     This is the UDP port to use for SNMP requests.   The  default  is
     161. This is mostly useful in testing. Note that port 161 is only
     available to a super-user; during  testing,  you  probably  don't
     want  to  run with super-user permissions, so you must use a port
     number > 1023.

   SNMP_QUEUE SNMPQUEUE
     This is the maximum number of messages  allowed  in  the  agent's
     message  queue.   The default is 50.  If there are more that this
     many SNMP requests outstanding at  any  time,  incoming  messages
     will be dropped.

   SNMP_TRAP SNMPTRAP
     This  is the UDP port to use for SNMP TRAP messages.  The default
     is 162.  The remarks for SNMP_PORT apply here also.

INETD

   This version of ndcagent may be started by inetd; it understands how inetd
   starts network services and cooperates.  To make this work, you should put
   a line into /etc/inetd.conf like:
      snmp dgram udp wait nm /etc/ndcagent
   Actually, it's probably better to have inetd start a script so you can set
   up ndcagent's environment.  A suggested approach is to use the line:
      snmp dgram udp wait nm /etc/snmp
   and make /etc/snmp a script that ends with
      exec $D/ndcagent
   where $D is the directory in which ndcagent is installed.  There should be
   a script called "snmp" accompanying this program; you might look at it for
   ideas (or just install it as /etc/snmp).

CONFIG FILE

   Most of ndcagent's parameters may be set in  its  config  file,  which  is
   "ndcagent.conf"  (in  "."  or  "/etc") by default; it can be named via the
   SNMPD_CONF environment variable.  The modification time of  this  file  is
   checked  occasionally (every 10 sec) by ndcagent, and if the file changes,
   ndcagent rereads it. The general syntax of an entry in the config file is:
      parameter:  value # comment

   You may use '#' anywhere (outside of quotes) to cause the rest of the line
   to be ignored.

   For parameters with string values, you may use single or double quotes. If
   you  omit  the quotes, the value will be the string before the first space
   or '#' on the line.  Thus single words need  not  be  quoted;  quotes  are
   needed  if there are special characters within the value, or if you want a
   null string as the value.  If in doubt, use quotes.

   Here are (some of) the parameters recognized by ndcagent at present.   New
   items  may  be  added  to this list at any time, so there may be some that
   aren't yet documented.  Unrecognized lines will produce a warning  message
   in the logfile, but are harmless. Note that the format is quite similar to
   other SNMP agents' config-file formats (especially HP's OpenLook, which is
   used  within  GTE),  so  you  may  be  able to use config files from other
   agents.

   debug: 4/tmp/ndcagent.log # Debug level and name.

      This sets the debug  level  to  4  and  the  output  logfile  to
      "tmp/ndcagent.log"  Note  that  when ndcagent rereads the config
      file, this line will cause it to close the logfile  and  open  a
      new one.

   backup: .3

      This tells ndcagent to respond to logfile-full (see the DBG_SIZE
      environment variable above) by renaming the logfile by appending
      a '.' and a digit; up to 3 such backups will be made,  and  then
      the older logfiles will be lost.

   env: NAME=value

      This adds NAME to the agent's environment list  with  the  given
      string  as  its  value.   Putting  this  in the config file will
      override the value passed in to the agent during startup (or  an
      earlier value from the config file).

   opt: <string>

      This treats the <string> as a command-line option. This lets you
      re-define  any of the command-line options by editing the config
      file.  Thus "opt:  -NXTpvc" will disable the GET-NEXT  operation
      for  swpvc variables.  "opt:  +m" will produce a new dump of the
      MIB table every time the config file is read.

   asn-fmt: 2     # ASN-dump format may be 1, 2 or 3.
   hex-fmt: 2     # Hex-dump format may be 1, 2 or 3.

      These define the formats of hex dumps at debug level 4  and  and
      higher,  and  symbolic  dumps  of ASN.1 (i.e., SNMP) messages at
      debug level 3 and higher.  The number is (roughly) the number of
      lines  that  are  produced.   See  the above descriptions of the
      ASN_FMT and HEX_FMT environment variables.

   get-community-name: NDC
   get-community-addr: 192.9.55.0
   get-community-mask: 0xFF000000

      These define an acceptable community string in SNMP GET requests
      and optionally a range of source addresses. If the addr and mask
      are defined, then the mask is anded with the  get-community-addr
      and the source IP address of a request, and if they don't match,
      the request is ignored.  This example will accept  GET  requests
      with  the community string "NDC" from any IP address with 192
      in its high-order byte.

   set-community-name: 'GTE NDC'
   set-community-addr:  192.9.200.36
   set-community-mask:  0xFFFFFF00

      These define an acceptable community string in SNMP SET requests
      and optionally a range of source addresses. If the addr and mask
      are defined, then the mask is anded with the source  IP  address
      of  a  request  and  the  set-community-addr,  and if they don't
      match, the set request is ignored.

   set-community-name: 'gbs0.GTE.com'
   get-community-name: 'gbs0.GTE.com'
   set-community-addr: 192.9.200.1
   set-community-mask: 0xFFFFFFFF

      This shows how one might define a community string  that  allows
      get and set requests from exactly one specific IP address.

   queue-len: 100   # Message queue limit.
      
      This is the maximum number of messages that the agent will  hold
      in its queue; the default is 50. When the queue is full, any new
      SNMP requests will be dropped.  The value  1  will  restore  the
      original one-message-at-a-time behavior.

   trap-dest: 127.0.0.1

      This tells ndcagent to send SNMP TRAP messages to the address.

   trap-dest: gbs35
   trap-comm: "GTE NDC" # This needs to be quoted.

      This adds another  TRAP  destination  to  the  list,  and  tells
      ndcagent which community string to include in the messages.

   exit: 5

      The agent will exit with this status. This is most useful during
      testing, as a way to tell ndcagent to quit if you don't have the
      right permissions to use a "kill" command.  As long as this line
      is  in  the config file, any new ndcagent that starts will exit.
      Then removing  (or  commenting  out)  the  line  will  re-enable
      ndcagent.

FILES

   /dev/kmem
      To implement the SNMP MIB, this program must  be  able  to  read
      from /dev/kmem. The conventional setup is: /dev/kmem is owned by
      the kmem group, and the user id used for testing must be in  the
      kmem group.  Alternatively, you can make ndcagent setgid-kmem.

   ndcagent.conf /etc/ndcagent.conf
      This file is read (if either name exists and is readable) for an
      assortment of values.  Actually, these are the default names for
      the config file; if SNMP_CONF is defined in the environment,  it
      will be used for the file name.

   snmp.addr
      The agent writes its IP address and port number to this file, as
      a 5-number dotted-decimal ASCII string.

   snmp.pid
      The agent writes its process id number in ASCII to this file.

   snmp.port
      The agent writes its UDP port number in ASCII to this file. This
      is the same as the last field in ndcagent.addr.

   The following files will be used for values  of  the  corresponding
   SNMP MIB variables:
     sysContact   (default is null)
     sysDescr     (default is from utsname)
     sysLocation  (default is null)
     sysName      (default is the hostname)

LOGFILE
DEBUGGING
   This agent has an extensive logfile  capability  built  in,  via  the  dbg
   package.   To  enable  logging,  you may use a command-line argument or an
   environment variable.  The environment variable is:
      setenv D_snmpd <l><file>
   where <l> is a one-digit debug/verbose level, and <file> is  the  name  of
   the output file.  For example:
      setenv D_snmpd 4/tmp/ndcagent.log
   will  cause  ndcagent  to  run  at  debug  level 4, and its output will be
   written to /tmp/ndcagent.log.  If you prefer to use a command-line option,
   you may start ndcagent via a command like:
      ndcagent -D5/usr/adm/ndcagent.log &
   This  will  start ndcagent at debug level 5, and its output will go to the
   ndcagent.log file in /usr/adm.

   Under normal circumstances, ndcagent should run at debug level 1. If there
   are  problems with SNMP, level 2 will give error and warning messages.  In
   an initial installation, when you want  some  verification  of  what  SNMP
   messages  are  being  sent,  you  may want to use levels 3 or 4 to see the
   contents of the messages.  Here are what the debug levels mean:
     0 Silent.
     1 Serious or fatal error messages.
     2 Message times; less serious warnings.
     3 Symbolic dumps of messages.
     4 Hex dumps of messages; some details of data routines.
     5 and up - only useful if you have the source.

   If ndcagent receives a CONT signal, the output logfile will be closed  and
   reopened.   You may use this after deleting or renaming the file, to get a
   new (empty) log file.

SEE ALSO
   ndcsnmpinstall
   syslog(8), variables(5), RFC 1065, RFC 1066, RFC 1067

INETD SUPPORT
   This agent can be started by inetd. It checks stdin (file 0), and if it is
   a  socket,  ndcagent  assumes  that inetd was the startup mechanism.  This
   allows the use of ndcagent as an "on-demand" background daemon.   It  also
   means that ndcagent need not run with super-user permissions.

BUGS

AUTHOR
   John Chambers
